@@ -7,6 +7,7 @@ from sphinx.ext.intersphinx import InventoryAdapter
 
 from .backref import CodeRefsVisitor, CodeExample
 from .block import CodeBlockAnalyser, SourceTransform, link_html
+from .directive import RemoveExtensionVisitor
 from .cache import DataCache
 from .resolve import resolve_location
 
@@ -30,6 +31,9 @@ class SphinxCodeAutoLink:
         self._inventory = {}
         self.outdated_docs: Set[str] = set()
         self.global_preface: List[str] = []
+        self.custom_blocks = None
+        self.concat_default = None
+        self.search_css_classes = None
 
     def build_inited(self, app):
         """Handle initial setup."""
@@ -40,6 +44,9 @@ class SphinxCodeAutoLink:
         self.cache = DataCache(app.doctreedir, app.srcdir)
         self.cache.read()
         self.outdated_docs = {str(Path(d)) for d in app.builder.get_outdated_docs()}
+        self.custom_blocks = app.config.codeautolink_custom_blocks
+        self.concat_default = app.config.codeautolink_concat_default
+        self.search_css_classes = app.config.codeautolink_search_css_classes
 
         # Append static resources path so references in setup() are valid
         app.config.html_static_path.append(
@@ -66,7 +73,11 @@ class SphinxCodeAutoLink:
             return
 
         visitor = CodeBlockAnalyser(
-            doctree, source_dir=app.srcdir, global_preface=self.global_preface
+            doctree,
+            source_dir=app.srcdir,
+            global_preface=self.global_preface,
+            custom_blocks=self.custom_blocks,
+            concat_default=self.concat_default,
         )
         doctree.walkabout(visitor)
         self.cache.transforms[visitor.current_document] = visitor.source_transforms
@@ -87,11 +98,11 @@ class SphinxCodeAutoLink:
     def generate_backref_tables(self, app, doctree, docname):
         """Generate backreference tables."""
         self.once_on_doctree_resolved(app)
-        visitor = CodeRefsVisitor(
-            doctree,
-            code_refs=self.code_refs,
-            remove_directives=self.do_nothing,
-        )
+        if self.do_nothing:
+            rm_vis = RemoveExtensionVisitor(doctree)
+            return doctree.walkabout(rm_vis)
+
+        visitor = CodeRefsVisitor(doctree, code_refs=self.code_refs)
         doctree.walk(visitor)
 
     def filter_and_resolve(self, transforms: List[SourceTransform], app):
@@ -136,8 +147,15 @@ class SphinxCodeAutoLink:
         for doc, transforms in self.cache.transforms.items():
             if not transforms or str(Path(doc)) not in self.outdated_docs:
                 continue
-            file = (Path(app.outdir) / doc).with_suffix('.html')
-            link_html(file, app.outdir, transforms, self.make_inventory(app))
+            file = Path(app.outdir) / (doc + '.html')
+            link_html(
+                file,
+                app.outdir,
+                transforms,
+                self.make_inventory(app),
+                self.custom_blocks,
+                self.search_css_classes,
+            )
 
         self.cache.write()
 
